@@ -57,11 +57,11 @@ use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: Convert any text file into template
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 with 'Dist::Zilla::Role::FileMunger';
 with 'Dist::Zilla::Role::FileFinderUser' => {
-    finder_arg_names => [ 'templates' ],
+    finder_arg_names => [ qw{ template templates } ],
     default_finders  => [ ':NoFiles' ],
 };
 with 'Dist::Zilla::Role::TextTemplater' => { -version => 0.004 };   # need `fill_in_file`.
@@ -69,6 +69,15 @@ with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =attr template
+#pod
+#pod =attr templates
+#pod
+#pod TODO
+#pod
+#pod
+#pod # --------------------------------------------------------------------------------------------------
+#pod
 #pod =method munge_files
 #pod
 #pod It is the only method of the plugin. It iterates through the files provided by C<<
@@ -123,7 +132,7 @@ Dist::Zilla::Plugin::Templates - Convert any text file into template
 
 =head1 VERSION
 
-Version 0.001, released on 2015-08-10 21:08 UTC.
+Version 0.002, released on 2015-08-11 23:13 UTC.
 
 =head1 WHAT?
 
@@ -144,6 +153,16 @@ L<readme|Dist::Zilla::Plugin::Templates::ReadMe>.
 Implementation of the plugin is trivial. It just consumes few roles which do all the work:
 C<FileFinderUser> provides a list of templates, C<TextTemplater> process them.
 
+=head1 OBJECT ATTRIBUTES
+
+=head2 template
+
+=head2 templates
+
+TODO
+
+# --------------------------------------------------------------------------------------------------
+
 =head1 OBJECT METHODS
 
 =head2 munge_files
